@@ -1,7 +1,7 @@
 package Desktop::Detect;
 
 our $DATE = '2015-06-05'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -50,9 +50,8 @@ sub detect_desktop {
 
         # gnome
         last DETECT if _det_env($info, 'gnome', 'DESKTOP_SESSION', 'gnome');
-
-        # gnome-classic
         last DETECT if _det_env($info, 'gnome-classic', 'DESKTOP_SESSION', 'gnome-classic');
+        last DETECT if _det_env($info, 'gnome-fallback', 'DESKTOP_SESSION', 'gnome-fallback');
 
         # lxde
         last DETECT if _det_env($info, 'lxde', 'XDG_MENU_PREFIX', 'lxde-');
@@ -83,7 +82,7 @@ Desktop::Detect - Detect desktop environment currently running
 
 =head1 VERSION
 
-This document describes version 0.04 of Desktop::Detect (from Perl distribution Desktop-Detect), released on 2015-06-05.
+This document describes version 0.05 of Desktop::Detect (from Perl distribution Desktop-Detect), released on 2015-06-05.
 
 =head1 SYNOPSIS
 
